@@ -116,7 +116,7 @@ pub fn solve(input: &mut Input) -> Result<u64, String> {
 
 #[test]
 pub fn tests() {
-    use crate::{test_part_one, test_part_two};
+    use crate::input::{test_part_one, test_part_two};
 
     let example = "Player 1:
 9
